#[repr(u32)]pub enum ParserTokenSetKind {
Intervals = 0,
Inline128 = 1,
Dense = 2,
}Expand description
Membership representation selected for one immutable parser token set.
Variants
Intervals = 0
Sorted, coalesced inclusive ranges searched by interval boundary.
Inline128 = 1
Two packed words covering EOF and token types 1..=127.
Dense = 2
A bounded packed word slice for a larger, cost-effective token domain.