Structs
- Error
Node - Typed error-node wrapper exposed by generated listener and visitor surfaces.
- Generated
Parse Output - Result from a generated parser entry point that retains the parser.
- Grammar
Metadata - Terminal
Node - Typed terminal wrapper exposed by generated listener, visitor, and context surfaces.
Traits
Functions
- lex
- Lexes UTF-8 text into an eagerly filled token stream without constructing a parser.
- lex_
stream - Lexes a caller-provided character stream without constructing a parser.