Skip to main contentModule generated
Source - ErrorNode
- Typed error-node wrapper exposed by generated listener and visitor
surfaces.
- GeneratedParseOutput
- Result from a generated
parse_with_parser or parse_stream_with_parser
call. - GrammarMetadata
- TerminalNode
- Typed terminal wrapper exposed by generated listener, visitor, and context
surfaces.
- GeneratedLexer
- GeneratedParser
- lex
- Lexes UTF-8 text into an eagerly filled token stream without constructing
a parser.
- lex_stream
- Lexes a caller-provided character stream without constructing a parser.