GrammarMetadata

Struct GrammarMetadata 

pub struct GrammarMetadata { /* private fields */ }

Implementations

Source

impl GrammarMetadata

pub const fn new( grammar_file_name: &'static str, rule_names: &'static [&'static str], literal_names: &'static [Option<&'static str>], symbolic_names: &'static [Option<&'static str>], display_names: &'static [Option<&'static str>], channel_names: &'static [&'static str], mode_names: &'static [&'static str], serialized_atn: &'static [i32], ) -> Self

Creates static grammar metadata emitted by the Rust target generator.

pub const fn grammar_file_name(&self) -> &'static str

pub const fn rule_names(&self) -> &'static [&'static str]

pub const fn channel_names(&self) -> &'static [&'static str]

pub const fn mode_names(&self) -> &'static [&'static str]

pub fn vocabulary(&self) -> Vocabulary

pub const fn serialized_atn(&self) -> SerializedAtn<'_>

Borrows the serialized ATN values for deserialization by the runtime simulators without copying generated static data.