Structs
- Bail
Error Strategy - Marker error strategy matching ANTLR’s
BailErrorStrategy. - Base
Parser - Expected
Token Set - Interval-set of expected token types, displayable through a vocabulary —
the shape ANTLR’s
getExpectedTokens().toString(vocabulary)exposes to generated test actions. - Generated
Diagnostics Checkpoint - Rollback marker for speculative generated parser paths.
- Generated
Match - Outcome of a generated token / set / not-set match that may recover.
- NoSemantic
Hooks - Default hook object used by parsers that do not need user-supplied semantics.
- Parser
Action - Parser semantic action reached while recognizing one ATN path.
- Parser
Member Action - Integer member mutation attached to an ATN action transition.
- Parser
Return Action - Integer return-value assignment attached to an ATN action transition.
- Parser
Rule Arg - Integer argument metadata for a generated parser rule invocation.
- Parser
Runtime Options - Optional generated-runtime metadata for metadata-driven parser execution.
- Parser
SemCtx - Runtime view passed to parser semantic hooks.
- Parser
Semantic Action - Parser action coordinate lowered into
SemIr. - Parser
Semantic Predicate - Parser predicate coordinate lowered into
SemIr. - Parser
Semantics - Data-driven semantic tables emitted by generated parsers.
Enums
- Parser
Predicate - Parser semantic predicate rendered from a supported target template.
- Prediction
Mode - Prediction strategy requested by generated parser harnesses.
- Unknown
Semantic Policy - Policy for semantic predicate coordinates that have no runtime implementation.
Traits
- Parser
- Semantic
Hooks - User extension point for parser semantic predicates and actions that the metadata generator did not translate into built-in runtime metadata.