pub struct ParseTreeStorage { /* private fields */ }Expand description
Flat, structure-of-arrays concrete syntax tree storage.
Every node is addressed by NodeId. Rule children occupy one range in
children; child_links is parser scratch used only while rule contexts
are open and is never exposed as part of the completed tree.
Implementations
Sourceimpl ParseTreeStorage
impl ParseTreeStorage
pub const fn new() -> Self
pub const fn node_count(&self) -> usize
pub const fn edge_count(&self) -> usize
pub const fn extra_count(&self) -> usize
pub const fn stats(&self) -> ParseTreeStats
pub fn node<'tree>( &'tree self, tokens: &'tree TokenStore, id: NodeId, ) -> Option<Node<'tree>>