pub struct ParserRuleContext { /* private fields */ }Implementations
Sourceimpl ParserRuleContext
impl ParserRuleContext
pub const fn new(rule_index: usize, invoking_state: isize) -> Self
pub const fn rule_index(&self) -> usize
pub const fn invoking_state(&self) -> isize
pub const fn alt_number(&self) -> usize
pub const fn set_alt_number(&mut self, alt_number: usize)
pub const fn start(&self) -> Option<&CommonToken>
pub const fn stop(&self) -> Option<&CommonToken>
pub fn set_start(&mut self, token: CommonToken)
pub fn set_stop(&mut self, token: CommonToken)
Sourcepub fn set_int_return(&mut self, name: impl Into<String>, value: i64)
pub fn set_int_return(&mut self, name: impl Into<String>, value: i64)
Stores a generated integer return value on this rule context.
Sourcepub fn int_return(&self, name: &str) -> Option<i64>
pub fn int_return(&self, name: &str) -> Option<i64>
Reads a generated integer return value from this rule context.
pub const fn exception(&self) -> Option<&AntlrError>
pub fn set_exception(&mut self, error: AntlrError)
pub fn children(&self) -> &[ParseTree]
pub fn add_child(&mut self, child: ParseTree)
pub fn text(&self) -> String
pub fn to_string_tree(&self, rule_names: &[String]) -> String